==> igniteui-react-charts-16.6.4.tgz: package/ES5/WeightedCloseIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { WeightedCloseIndicatorStrategy } from "./WeightedCloseIndicatorStrategy";
import { markType } from "igniteui-react-core/ES5/type";
var WeightedCloseIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(WeightedCloseIndicator, _super);
    function WeightedCloseIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WeightedCloseIndicator.prototype.get_qp = function () {
        return new WeightedCloseIndicatorStrategy();
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    WeightedCloseIndicator.prototype.get_qg = function () {
        return WeightedCloseIndicator.$;
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "qg", {
        get: function () {
            return this.get_qg();
        },
        enumerable: true,
        configurable: true
    });
    WeightedCloseIndicator.$t = markType(WeightedCloseIndicator, 'WeightedCloseIndicator', ItemwiseStrategyBasedIndicator.$);
    return WeightedCloseIndicator;
}(ItemwiseStrategyBasedIndicator));
export { WeightedCloseIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/WeightedCloseIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { WeightedCloseIndicatorStrategy } from "./WeightedCloseIndicatorStrategy";
import { markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var WeightedCloseIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(WeightedCloseIndicator, _super);
    function WeightedCloseIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WeightedCloseIndicator.prototype.get_qr = function () {
        return new WeightedCloseIndicatorStrategy();
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "qr", {
        get: function () {
            return this.get_qr();
        },
        enumerable: true,
        configurable: true
    });
    WeightedCloseIndicator.prototype.get_qi = function () {
        return WeightedCloseIndicator.$;
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    WeightedCloseIndicator.$t = markType(WeightedCloseIndicator, 'WeightedCloseIndicator', ItemwiseStrategyBasedIndicator.$);
    return WeightedCloseIndicator;
}(ItemwiseStrategyBasedIndicator));
export { WeightedCloseIndicator };
